@@ -46,9 +46,8 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
     let token_manager_seeds = &[TOKEN_MANAGER_SEED.as_bytes(), mint.as_ref(), &[token_manager.bump]];
     let token_manager_signer = &[&token_manager_seeds[..]];
 
-    if token_manager.kind == TokenManagerKind::Managed as u8 {
-        // if claimed we need to thaw
-        if token_manager.state == TokenManagerState::Claimed as u8 {
+    if token_manager.state == TokenManagerState::Claimed as u8 {
+        if token_manager.kind == TokenManagerKind::Managed as u8 {
             // thaw recipient account
             let cpi_accounts = ThawAccount {
                 account: ctx.accounts.recipient_token_account.to_account_info(),
@@ -58,42 +57,35 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
             let cpi_program = ctx.accounts.token_program.to_account_info();
             let cpi_context = CpiContext::new(cpi_program, cpi_accounts).with_signer(token_manager_signer);
             token::thaw_account(cpi_context)?;
+            
+        } else if token_manager.kind == TokenManagerKind::Edition as u8 {
+            let remaining_accs = &mut ctx.remaining_accounts.iter();
+            let edition_info = next_account_info(remaining_accs)?;
+            let metadata_program = next_account_info(remaining_accs)?;
 
+            // edition will be validated by metadata_program
+            assert_keys_eq!(metadata_program.key, mpl_token_metadata::id());
+            
+            invoke_signed(
+                &freeze_delegated_account(
+                    *metadata_program.key,
+                    token_manager.key(),
+                    ctx.accounts.recipient_token_account.key(),
+                    *edition_info.key,
+                    ctx.accounts.mint.key(),
+                ),
+                &vec![
+                    token_manager.to_account_info(),
+                    ctx.accounts.recipient_token_account.to_account_info(),
+                    edition_info.to_account_info(),
+                    ctx.accounts.mint.to_account_info(),
+                ],
+                &[token_manager_seeds],
+            )?;
         }
-        // transfer back to issuer
-        let cpi_accounts = Transfer {
-            from: ctx.accounts.recipient_token_account.to_account_info(),
-            to: ctx.accounts.issuer_token_account.to_account_info(),
-            authority: token_manager.to_account_info(),
-        };
-        let cpi_program = ctx.accounts.token_program.to_account_info();
-        let cpi_context = CpiContext::new(cpi_program, cpi_accounts).with_signer(token_manager_signer);
-        token::transfer(cpi_context, token_manager.amount)?;
-    } else if token_manager.kind == TokenManagerKind::Edition as u8 {
-        let remaining_accs = &mut ctx.remaining_accounts.iter();
-        let edition_info = next_account_info(remaining_accs)?;
-        let metadata_program = next_account_info(remaining_accs)?;
-
-        // edition will be validated by metadata_program
-        assert_keys_eq!(metadata_program.key, mpl_token_metadata::id());
-        
-        invoke_signed(
-            &freeze_delegated_account(
-                *metadata_program.key,
-                token_manager.key(),
-                ctx.accounts.recipient_token_account.key(),
-                *edition_info.key,
-                ctx.accounts.mint.key(),
-            ),
-            &vec![
-                token_manager.to_account_info(),
-                ctx.accounts.recipient_token_account.to_account_info(),
-                edition_info.to_account_info(),
-                ctx.accounts.mint.to_account_info(),
-            ],
-            &[token_manager_seeds],
-        )?;
+    }
 
+    if token_manager.invalidation_type == InvalidationType::Return as u8 {
         // transfer back to issuer
         let cpi_accounts = Transfer {
             from: ctx.accounts.recipient_token_account.to_account_info(),
@@ -104,7 +96,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
         let cpi_context = CpiContext::new(cpi_program, cpi_accounts).with_signer(token_manager_signer);
         token::transfer(cpi_context, token_manager.amount)?;
     }
-    
+
     token_manager.state = TokenManagerState::Invalidated as u8;
 
     // close token_manager_token_account
