@@ -8,6 +8,7 @@ use {
 pub struct IssueIx {
     pub amount: u64,
     pub kind: u8,
+    pub invalidation_type: u8,
 }
 
 #[derive(Accounts)]
@@ -40,11 +41,17 @@ pub fn handler(ctx: Context<IssueCtx>, ix: IssueIx) -> ProgramResult {
         && ix.kind != TokenManagerKind::Edition as u8 {
         return Err(ErrorCode::InvalidTokenManagerKind.into());
     }
+    if ix.invalidation_type != InvalidationType::Return as u8
+        && ix.invalidation_type != InvalidationType::Invalidate as u8 {
+        return Err(ErrorCode::InvalidInvalidationType.into());
+    }
+
     // set token manager data
     let token_manager = &mut ctx.accounts.token_manager;
     token_manager.mint = ctx.accounts.mint.key();
     token_manager.amount = ix.amount;
     token_manager.kind = ix.kind;
+    token_manager.invalidation_type = ix.invalidation_type;
     token_manager.state = TokenManagerState::Issued as u8;
 
     // transfer token to token manager token account
